@@ -125,7 +125,8 @@ static void gconf_client_finalize              (GObject* object);
 
 static gboolean gconf_client_cache          (GConfClient *client,
                                              gboolean     take_ownership,
-                                             GConfEntry  *entry);
+                                             GConfEntry  *entry,
+                                             gboolean    preserve_schema_name);
 
 static gboolean gconf_client_lookup         (GConfClient *client,
                                              const char  *key,
@@ -406,7 +407,7 @@ notify_from_server_callback (GConfEngine* conf, guint cnxn_id,
    * listeners or functions connected to value_changed.
    * We know this key is under a directory in our dir list.
    */
-  changed = gconf_client_cache (client, FALSE, entry);                                
+  changed = gconf_client_cache (client, FALSE, entry, TRUE);
 
   if (!changed)
     return; /* don't do the notify */
@@ -545,7 +546,7 @@ gconf_client_add_dir     (GConfClient* client,
 
   g_return_if_fail (gconf_valid_key (dirname, NULL));
 
-  trace ("Adding dir '%s'\n", dirname);
+  trace ("Adding directory '%s'\n", dirname);
   
   d = g_hash_table_lookup (client->dir_hash, dirname);
 
@@ -683,7 +684,7 @@ gconf_client_remove_dir  (GConfClient* client,
 {
   Dir* found = NULL;
 
-  trace ("Removing dir '%s'\n", dirname);
+  trace ("Removing directory '%s'\n", dirname);
   
   found = g_hash_table_lookup (client->dir_hash,
                                dirname);
@@ -759,6 +760,7 @@ gconf_client_notify (GConfClient* client, const char* key)
   if (entry != NULL)
     {
       notify_one_entry (client, entry);
+      gconf_entry_unref (entry);
     }
 }
 
@@ -775,7 +777,6 @@ gconf_client_set_error_handling(GConfClient* client,
 static gboolean
 clear_cache_foreach (char* key, GConfEntry* entry, GConfClient* client)
 {
-  g_free (key);
   gconf_entry_free (entry);
 
   return TRUE;
@@ -870,7 +871,7 @@ cache_entry_list_destructively (GConfClient *client,
     {
       GConfEntry* entry = tmp->data;
       
-      gconf_client_cache (client, TRUE, entry);
+      gconf_client_cache (client, TRUE, entry, FALSE);
       
       tmp = g_slist_next (tmp);
     }
@@ -1111,7 +1112,7 @@ gconf_client_dir_exists(GConfClient* client,
   GError* error = NULL;
   gboolean retval;
 
-  trace ("Checking whether dir '%s' exists...\n", dir);
+  trace ("Checking whether directory '%s' exists...\n", dir);
   
   PUSH_USE_ENGINE (client);
   retval = gconf_engine_dir_exists (client->engine, dir, &error);
@@ -1238,7 +1239,7 @@ get (GConfClient *client,
       if (key_being_monitored (client, key))
         {
           /* cache a copy of val */
-          gconf_client_cache (client, FALSE, entry);
+          gconf_client_cache (client, FALSE, entry, FALSE);
         }
 
       /* We don't own the entry, we're returning this copy belonging
@@ -1881,7 +1882,8 @@ gconf_client_value_changed          (GConfClient* client,
 static gboolean
 gconf_client_cache (GConfClient *client,
                     gboolean     take_ownership,
-                    GConfEntry  *new_entry)
+                    GConfEntry  *new_entry,
+                    gboolean     preserve_schema_name)
 {
   gpointer oldkey = NULL, oldval = NULL;
 
@@ -1903,6 +1905,10 @@ gconf_client_cache (GConfClient *client,
           if (!take_ownership)
             new_entry = gconf_entry_copy (new_entry);
           
+          if (preserve_schema_name)
+            gconf_entry_set_schema_name (new_entry, 
+                                         gconf_entry_get_schema_name (entry));
+
           g_hash_table_replace (client->cache_hash,
                                 new_entry->key,
                                 new_entry);
